using Godot;
using System;

public class BuildModeUI : Control
{
    [Signal]
    delegate void OnExit();

    [Export]
    private NodePath _buildModePath;
    private BuildMode _buildMode;

    // Called when the node enters the scene tree for the first time.
    public override void _Ready()
    {
        _buildMode = GetNode<BuildMode>(_buildModePath);

        var buttonHeight = 40;
        var tileType = _buildMode.BuildableTiles[0];
        int x = 50;

        SpawnButton(tileType, buttonHeight, ref x);
    }

    private void SpawnButton(TileType tileType, int buttonHeight, ref int x)
    {
        const int MARGIN = 5;

        var button = new Button();
        this.AddChild(button);

        button.Text = tileType.Name;
        var parameters = new Godot.Collections.Array(tileType);
        button.Connect("pressed", this, nameof(SelectTileType), parameters);

        button.SetAnchorsPreset(LayoutPreset.BottomLeft);
        button.MarginBottom = 0;

        var size = button.RectSize;
        button.RectSize = new Vector2(size.x, buttonHeight);

        button.SetPosition(new Vector2(x, -buttonHeight));
        x += Mathf.RoundToInt(size.x) + MARGIN;
    }

    private void SelectTileType(TileType tileType)
    {
        _buildMode.SelectedTileType = tileType;
    }

    public void Exit()
    {
        EmitSignal(nameof(OnExit));
    }

    public override void _Process(float delta)
    {
        base._Process(delta);

        Visible = _buildMode.Active;
    }
}
